# -*- coding: utf-8 -*-

from __future__ import unicode_literals


__author__ = 'Mohammad Faraji'
__version__ = '0.4.2.8'


default_app_config = 'rangefilter_jalali.apps.RangeFilterConfig'


VERSION = __version__
