{% load i18n rangefilter_compat jformat%}
<h3>{% blocktrans with filter_title=title %}By {{ filter_title }}{% endblocktrans %}</h3>
<link rel="stylesheet" type="text/css" href="{% static 'admin/css/widgets.css' %}">
<link rel="stylesheet" type="text/css" href="{% static 'admin/jquery.ui.datepicker.jalali/themes/base/jquery-ui.min.css' %}">
<link rel="stylesheet" type="text/css" href="{% static 'admin/css/main.css' %}">
<style>
    .button, input[type=submit], input[type=button], .submit-row input, a.button,
    .button, input[type=reset] {
        background: #79aec8;
        padding: 4px 5px;
        border: none;
        border-radius: 4px;
        color: #fff;
        cursor: pointer;
    }
    .admindatefilter {
        padding-left: 15px;
        padding-bottom: 10px;
        border-bottom: 1px solid #eaeaea;
    }
    .admindatefilter p {
        padding-left: 0px;
        line-height: 0;
    }
    .admindatefilter p.datetime {
        line-height: 0;
    }
    .admindatefilter .timezonewarning {
        display: none;
    }
    .admindatefilter .datetimeshortcuts a:first-child {
        margin-right: 4px;
        display: none;
    }
    .calendarbox {
        z-index: 1100;
    }
    .clockbox {
        z-index: 1100;
        margin-left: 22em !important;
        margin-top: 2em !important;
    }
    .admindatefilter .datetimeshortcuts {
        font-size: 0;
        float: right;
        position: absolute;
        padding-top: 4px;
    }
    .admindatefilter a {
        color: #999;
        position: absolute;
        padding-top: 3px;
        padding-left: 4px;
    }
    @media (min-width: 768px) {
        .calendarbox {
            margin-left: 29em !important;
            margin-top: 6em !important;
        }
    }
    @media (max-width: 767px) {
        .calendarbox {
            overflow: visible;
        }
    }
</style>
<!--
Force load jsi18n, issues #5
https://github.com/django/django/blob/stable/1.10.x/django/contrib/admin/templates/admin/change_list.html#L7
-->
<script type="text/javascript" src="{% url 'admin:jsi18n' %}"></script>
<script src="{% static 'admin/jquery.ui.datepicker.jalali/scripts/jquery-1.10.2.min.js' %}"></script>
<script src="{% static 'admin/jquery.ui.datepicker.jalali/scripts/jquery.ui.core.js' %}"></script>
<script src="{% static 'admin/jquery.ui.datepicker.jalali/scripts/jquery.ui.datepicker-cc.js' %}"></script>
<script src="{% static 'admin/jquery.ui.datepicker.jalali/scripts/calendar.js' %}"></script>
<script src="{% static 'admin/jquery.ui.datepicker.jalali/scripts/jquery.ui.datepicker-cc-fa.js' %}"></script>
<script src="{% static 'admin/main.js' %}"></script>
<script>
    function datefilter_apply(event, qs_name, form_name){
        event.preventDefault();
        var query_string = django.jQuery('input#'+qs_name).val();
        var form_data = django.jQuery('#'+form_name).serialize();
        window.location = window.location.pathname + query_string + '&' + form_data;
    }
    function datefilter_reset(qs_name){
        var query_string = django.jQuery('input#'+qs_name).val();
        window.location = window.location.pathname + query_string;
    }
</script>
<script>
    // Code below makes sure that the DateTimeShortcuts.js is loaded exactly once
    // regardless the presence of AdminDateWidget
    // How it worked:
    //  - First Django loads the model formset with predefined widgets for different
    //    field types. If there's a date based field, then it loads the AdminDateWidget
    //    and it's required media to context under {{media.js}} in admin/change_list.html.
    //    (Note: it accumulates media in django.forms.widgets.Media object,
    //    which prevents duplicates, but the DateRangeFilter is not included yet
    //    since it's not model field related.
    //    List of predefined widgets is in django.contrib.admin.options.FORMFIELD_FOR_DBFIELD_DEFAULTS)
    //  - After that Django starts rendering forms, which have the {{form.media}}
    //    tag. Only then the DjangoRangeFilter.get_media is called and rendered,
    //    which creates the duplicates.
    // How it works:
    //  - first step is the same, if there's a AdminDateWidget to be loaded then
    //    nothing changes
    //  - DOM gets rendered and if the AdminDateWidget was rendered then
    //    the DateTimeShortcuts.js is initiated which sets the window.DateTimeShortcuts.
    //    Otherwise, the window.DateTimeShortcuts is undefined.
    //  - The lines below check if the DateTimeShortcuts has been set and if not
    //    then the DateTimeShortcuts.js and calendar.js is rendered
    //
    //  https://github.com/silentsokolov/django-admin-rangefilter/issues/9
    //
    // Django 2.1
    //  https://github.com/silentsokolov/django-admin-rangefilter/issues/21
    //
    django.jQuery('document').ready(function () {
        if (!('DateTimeShortcuts' in window)) {
            django.jQuery.when(
                {% for m in spec.form.js %}
                    django.jQuery.getScript('{{m}}'),
                {% endfor %}
                django.jQuery.Deferred(function( deferred ){
                    django.jQuery( deferred.resolve );
                })
            ).done(function(){
                django.jQuery('.datetimeshortcuts').remove();
                DateTimeShortcuts.init();
            });
        }
    });
</script>
<div class="admindatefilter">
    <form method="GET" action="." id="{{ choices.0.system_name }}-form">
        {{ spec.form.as_p }}
        {% for choice in choices %}
            <input type="hidden" id="{{ choice.system_name }}-query-string" value="{{ choice.query_string }}">
        {% endfor %}
        <div class="controls">
            <input type="submit" value="{% trans "Search" %}" onclick="datefilter_apply(event, '{{ choices.0.system_name }}-query-string', '{{ choices.0.system_name }}-form')">
            <input type="reset" class="button" value="{% trans "Reset" %}" onclick="datefilter_reset('{{ choices.0.system_name }}-query-string')">
        </div>
    </form>
</div>
